package com.ruoyi.system.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.system.domain.NightMarket;

/**
 * 夜市Mapper接口
 *
 * @author ruoyi
 * @date 2025-09-02
 */
public interface NightMarketMapper  extends BaseMapper<NightMarket>
{
    /**
     * 查询夜市
     *
     * @param id 夜市主键
     * @return 夜市
     */
    public NightMarket selectNightMarketById(Long id);

    /**
     * 查询夜市列表
     *
     * @param nightMarket 夜市
     * @return 夜市集合
     */
    public List<NightMarket> selectNightMarketList(NightMarket nightMarket);

    /**
     * 新增夜市
     *
     * @param nightMarket 夜市
     * @return 结果
     */
    public int insertNightMarket(NightMarket nightMarket);

    /**
     * 修改夜市
     *
     * @param nightMarket 夜市
     * @return 结果
     */
    public int updateNightMarket(NightMarket nightMarket);

    /**
     * 删除夜市
     *
     * @param id 夜市主键
     * @return 结果
     */
    public int deleteNightMarketById(Long id);

    /**
     * 批量删除夜市
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteNightMarketByIds(Long[] ids);
}
