package com.ruoyi.web.controller.system;

import java.util.List;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.NightMarket;
import com.ruoyi.system.service.INightMarketService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 夜市Controller
 *
 * @author ruoyi
 * @date 2025-09-02
 */
@RestController
@RequestMapping("/system/market")
public class NightMarketController extends BaseController
{
    @Autowired
    private INightMarketService nightMarketService;

    /**
     * 查询夜市列表
     */
    @PreAuthorize("@ss.hasPermi('system:market:list')")
    @GetMapping("/list")
    public TableDataInfo list(NightMarket nightMarket)
    {
        startPage();
        List<NightMarket> list = nightMarketService.selectNightMarketList(nightMarket);
        return getDataTable(list);
    }

    /**
     * 导出夜市列表
     */
    @PreAuthorize("@ss.hasPermi('system:market:export')")
    @Log(title = "夜市", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, NightMarket nightMarket)
    {
        List<NightMarket> list = nightMarketService.selectNightMarketList(nightMarket);
        ExcelUtil<NightMarket> util = new ExcelUtil<NightMarket>(NightMarket.class);
        util.exportExcel(response, list, "夜市数据");
    }

    /**
     * 获取夜市详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:market:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(nightMarketService.selectNightMarketById(id));
    }

    /**
     * 新增夜市
     */
    @PreAuthorize("@ss.hasPermi('system:market:add')")
    @Log(title = "夜市", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody NightMarket nightMarket)
    {
        return toAjax(nightMarketService.insertNightMarket(nightMarket));
    }

    /**
     * 修改夜市
     */
    @PreAuthorize("@ss.hasPermi('system:market:edit')")
    @Log(title = "夜市", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody NightMarket nightMarket)
    {
        return toAjax(nightMarketService.updateNightMarket(nightMarket));
    }

    /**
     * 删除夜市
     */
    @PreAuthorize("@ss.hasPermi('system:market:remove')")
    @Log(title = "夜市", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(nightMarketService.deleteNightMarketByIds(ids));
    }
}
